# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.beta.models.approval_comment import ApprovalComment
from sailpoint.beta.models.approval_description import ApprovalDescription
from sailpoint.beta.models.approval_identity import ApprovalIdentity
from sailpoint.beta.models.approval_name import ApprovalName
from sailpoint.beta.models.approval_reference import ApprovalReference
from typing import Optional, Set
from typing_extensions import Self

class Approval(BaseModel):
    """
    Approval Object
    """ # noqa: E501
    approval_id: Optional[StrictStr] = Field(default=None, description="The Approval ID", alias="approvalId")
    approvers: Optional[List[ApprovalIdentity]] = Field(default=None, description="Object representation of an approver of an approval")
    created_date: Optional[StrictStr] = Field(default=None, description="Date the approval was created", alias="createdDate")
    type: Optional[StrictStr] = Field(default=None, description="Type of approval")
    name: Optional[List[ApprovalName]] = Field(default=None, description="The name of the approval for a given locale")
    batch_request: Optional[Dict[str, Any]] = Field(default=None, description="The name of the approval for a given locale", alias="batchRequest")
    description: Optional[List[ApprovalDescription]] = Field(default=None, description="The description of the approval for a given locale")
    priority: Optional[StrictStr] = Field(default=None, description="The priority of the approval")
    requester: Optional[Dict[str, Any]] = Field(default=None, description="Object representation of the requester of the approval")
    comments: Optional[List[ApprovalComment]] = Field(default=None, description="Object representation of a comment on the approval")
    approved_by: Optional[List[ApprovalIdentity]] = Field(default=None, description="Array of approvers who have approved the approval", alias="approvedBy")
    rejected_by: Optional[List[ApprovalIdentity]] = Field(default=None, description="Array of approvers who have rejected the approval", alias="rejectedBy")
    completed_date: Optional[StrictStr] = Field(default=None, description="Date the approval was completed", alias="completedDate")
    approval_criteria: Optional[StrictStr] = Field(default=None, description="Criteria that needs to be met for an approval to be marked as approved", alias="approvalCriteria")
    status: Optional[StrictStr] = Field(default=None, description="The current status of the approval")
    additional_attributes: Optional[StrictStr] = Field(default=None, description="Json string representing additional attributes known about the object to be approved.", alias="additionalAttributes")
    reference_data: Optional[List[ApprovalReference]] = Field(default=None, description="Reference data related to the approval", alias="referenceData")
    __properties: ClassVar[List[str]] = ["approvalId", "approvers", "createdDate", "type", "name", "batchRequest", "description", "priority", "requester", "comments", "approvedBy", "rejectedBy", "completedDate", "approvalCriteria", "status", "additionalAttributes", "referenceData"]

    @field_validator('priority')
    def priority_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['HIGH', 'MEDIUM', 'LOW']):
            warnings.warn(f"must be one of enum values ('HIGH', 'MEDIUM', 'LOW') unknown value: {value}")
        return value

    @field_validator('approval_criteria')
    def approval_criteria_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['SINGLE', 'DOUBLE', 'TRIPLE', 'QUARTER', 'HALF', 'ALL']):
            warnings.warn(f"must be one of enum values ('SINGLE', 'DOUBLE', 'TRIPLE', 'QUARTER', 'HALF', 'ALL') unknown value: {value}")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['PENDING', 'APPROVED', 'REJECTED']):
            warnings.warn(f"must be one of enum values ('PENDING', 'APPROVED', 'REJECTED') unknown value: {value}")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Approval from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in approvers (list)
        _items = []
        if self.approvers:
            for _item_approvers in self.approvers:
                if _item_approvers:
                    _items.append(_item_approvers.to_dict())
            _dict['approvers'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in name (list)
        _items = []
        if self.name:
            for _item_name in self.name:
                if _item_name:
                    _items.append(_item_name.to_dict())
            _dict['name'] = _items
        # override the default output from pydantic by calling `to_dict()` of batch_request
        if self.batch_request:
            _dict['batchRequest'] = self.batch_request.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in description (list)
        _items = []
        if self.description:
            for _item_description in self.description:
                if _item_description:
                    _items.append(_item_description.to_dict())
            _dict['description'] = _items
        # override the default output from pydantic by calling `to_dict()` of requester
        if self.requester:
            _dict['requester'] = self.requester.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in comments (list)
        _items = []
        if self.comments:
            for _item_comments in self.comments:
                if _item_comments:
                    _items.append(_item_comments.to_dict())
            _dict['comments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in approved_by (list)
        _items = []
        if self.approved_by:
            for _item_approved_by in self.approved_by:
                if _item_approved_by:
                    _items.append(_item_approved_by.to_dict())
            _dict['approvedBy'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in rejected_by (list)
        _items = []
        if self.rejected_by:
            for _item_rejected_by in self.rejected_by:
                if _item_rejected_by:
                    _items.append(_item_rejected_by.to_dict())
            _dict['rejectedBy'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in reference_data (list)
        _items = []
        if self.reference_data:
            for _item_reference_data in self.reference_data:
                if _item_reference_data:
                    _items.append(_item_reference_data.to_dict())
            _dict['referenceData'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Approval from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "approvalId": obj.get("approvalId"),
            "approvers": [ApprovalIdentity.from_dict(_item) for _item in obj["approvers"]] if obj.get("approvers") is not None else None,
            "createdDate": obj.get("createdDate"),
            "type": obj.get("type"),
            "name": [ApprovalName.from_dict(_item) for _item in obj["name"]] if obj.get("name") is not None else None,
            "batchRequest": ApprovalBatch.from_dict(obj["batchRequest"]) if obj.get("batchRequest") is not None else None,
            "description": [ApprovalDescription.from_dict(_item) for _item in obj["description"]] if obj.get("description") is not None else None,
            "priority": obj.get("priority"),
            "requester": ApprovalIdentity.from_dict(obj["requester"]) if obj.get("requester") is not None else None,
            "comments": [ApprovalComment.from_dict(_item) for _item in obj["comments"]] if obj.get("comments") is not None else None,
            "approvedBy": [ApprovalIdentity.from_dict(_item) for _item in obj["approvedBy"]] if obj.get("approvedBy") is not None else None,
            "rejectedBy": [ApprovalIdentity.from_dict(_item) for _item in obj["rejectedBy"]] if obj.get("rejectedBy") is not None else None,
            "completedDate": obj.get("completedDate"),
            "approvalCriteria": obj.get("approvalCriteria"),
            "status": obj.get("status"),
            "additionalAttributes": obj.get("additionalAttributes"),
            "referenceData": [ApprovalReference.from_dict(_item) for _item in obj["referenceData"]] if obj.get("referenceData") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from sailpoint.v2025.models.access_profile_ref import AccessProfileRef
from sailpoint.v2025.models.attribute_dto_list import AttributeDTOList
from sailpoint.v2025.models.dimension_ref import DimensionRef
from sailpoint.v2025.models.entitlement_ref import EntitlementRef
from sailpoint.v2025.models.owner_reference import OwnerReference
from sailpoint.v2025.models.requestability_for_role import RequestabilityForRole
from sailpoint.v2025.models.revocability_for_role import RevocabilityForRole
from sailpoint.v2025.models.role_membership_selector import RoleMembershipSelector
from typing import Optional, Set
from typing_extensions import Self

class Role(BaseModel):
    """
    A Role
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The id of the Role. This field must be left null when creating an Role, otherwise a 400 Bad Request error will result.")
    name: Annotated[str, Field(strict=True, max_length=128)] = Field(description="The human-readable display name of the Role")
    created: Optional[datetime] = Field(default=None, description="Date the Role was created")
    modified: Optional[datetime] = Field(default=None, description="Date the Role was last modified.")
    description: Optional[StrictStr] = Field(default=None, description="A human-readable description of the Role")
    owner: Optional[OwnerReference]
    access_profiles: Optional[List[AccessProfileRef]] = Field(default=None, alias="accessProfiles")
    entitlements: Optional[List[EntitlementRef]] = None
    membership: Optional[RoleMembershipSelector] = None
    legacy_membership_info: Optional[Dict[str, Any]] = Field(default=None, description="This field is not directly modifiable and is generally expected to be *null*. In very rare instances, some Roles may have been created using membership selection criteria that are no longer fully supported. While these Roles will still work, they should be migrated to STANDARD or IDENTITY_LIST selection criteria. This field exists for informational purposes as an aid to such migration.", alias="legacyMembershipInfo")
    enabled: Optional[StrictBool] = Field(default=False, description="Whether the Role is enabled or not.")
    requestable: Optional[StrictBool] = Field(default=False, description="Whether the Role can be the target of access requests.")
    access_request_config: Optional[RequestabilityForRole] = Field(default=None, alias="accessRequestConfig")
    revocation_request_config: Optional[RevocabilityForRole] = Field(default=None, alias="revocationRequestConfig")
    segments: Optional[List[StrictStr]] = Field(default=None, description="List of IDs of segments, if any, to which this Role is assigned.")
    dimensional: Optional[StrictBool] = Field(default=False, description="Whether the Role is dimensional.")
    dimension_refs: Optional[List[DimensionRef]] = Field(default=None, description="List of references to dimensions to which this Role is assigned. This field is only relevant if the Role is dimensional.", alias="dimensionRefs")
    access_model_metadata: Optional[AttributeDTOList] = Field(default=None, alias="accessModelMetadata")
    __properties: ClassVar[List[str]] = ["id", "name", "created", "modified", "description", "owner", "accessProfiles", "entitlements", "membership", "legacyMembershipInfo", "enabled", "requestable", "accessRequestConfig", "revocationRequestConfig", "segments", "dimensional", "dimensionRefs", "accessModelMetadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Role from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "created",
            "modified",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in access_profiles (list)
        _items = []
        if self.access_profiles:
            for _item_access_profiles in self.access_profiles:
                if _item_access_profiles:
                    _items.append(_item_access_profiles.to_dict())
            _dict['accessProfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in entitlements (list)
        _items = []
        if self.entitlements:
            for _item_entitlements in self.entitlements:
                if _item_entitlements:
                    _items.append(_item_entitlements.to_dict())
            _dict['entitlements'] = _items
        # override the default output from pydantic by calling `to_dict()` of membership
        if self.membership:
            _dict['membership'] = self.membership.to_dict()
        # override the default output from pydantic by calling `to_dict()` of access_request_config
        if self.access_request_config:
            _dict['accessRequestConfig'] = self.access_request_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of revocation_request_config
        if self.revocation_request_config:
            _dict['revocationRequestConfig'] = self.revocation_request_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in dimension_refs (list)
        _items = []
        if self.dimension_refs:
            for _item_dimension_refs in self.dimension_refs:
                if _item_dimension_refs:
                    _items.append(_item_dimension_refs.to_dict())
            _dict['dimensionRefs'] = _items
        # override the default output from pydantic by calling `to_dict()` of access_model_metadata
        if self.access_model_metadata:
            _dict['accessModelMetadata'] = self.access_model_metadata.to_dict()
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if owner (nullable) is None
        # and model_fields_set contains the field
        if self.owner is None and "owner" in self.model_fields_set:
            _dict['owner'] = None

        # set to None if access_profiles (nullable) is None
        # and model_fields_set contains the field
        if self.access_profiles is None and "access_profiles" in self.model_fields_set:
            _dict['accessProfiles'] = None

        # set to None if membership (nullable) is None
        # and model_fields_set contains the field
        if self.membership is None and "membership" in self.model_fields_set:
            _dict['membership'] = None

        # set to None if legacy_membership_info (nullable) is None
        # and model_fields_set contains the field
        if self.legacy_membership_info is None and "legacy_membership_info" in self.model_fields_set:
            _dict['legacyMembershipInfo'] = None

        # set to None if segments (nullable) is None
        # and model_fields_set contains the field
        if self.segments is None and "segments" in self.model_fields_set:
            _dict['segments'] = None

        # set to None if dimensional (nullable) is None
        # and model_fields_set contains the field
        if self.dimensional is None and "dimensional" in self.model_fields_set:
            _dict['dimensional'] = None

        # set to None if dimension_refs (nullable) is None
        # and model_fields_set contains the field
        if self.dimension_refs is None and "dimension_refs" in self.model_fields_set:
            _dict['dimensionRefs'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Role from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "description": obj.get("description"),
            "owner": OwnerReference.from_dict(obj["owner"]) if obj.get("owner") is not None else None,
            "accessProfiles": [AccessProfileRef.from_dict(_item) for _item in obj["accessProfiles"]] if obj.get("accessProfiles") is not None else None,
            "entitlements": [EntitlementRef.from_dict(_item) for _item in obj["entitlements"]] if obj.get("entitlements") is not None else None,
            "membership": RoleMembershipSelector.from_dict(obj["membership"]) if obj.get("membership") is not None else None,
            "legacyMembershipInfo": obj.get("legacyMembershipInfo"),
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else False,
            "requestable": obj.get("requestable") if obj.get("requestable") is not None else False,
            "accessRequestConfig": RequestabilityForRole.from_dict(obj["accessRequestConfig"]) if obj.get("accessRequestConfig") is not None else None,
            "revocationRequestConfig": RevocabilityForRole.from_dict(obj["revocationRequestConfig"]) if obj.get("revocationRequestConfig") is not None else None,
            "segments": obj.get("segments"),
            "dimensional": obj.get("dimensional") if obj.get("dimensional") is not None else False,
            "dimensionRefs": [DimensionRef.from_dict(_item) for _item in obj["dimensionRefs"]] if obj.get("dimensionRefs") is not None else None,
            "accessModelMetadata": AttributeDTOList.from_dict(obj["accessModelMetadata"]) if obj.get("accessModelMetadata") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated
from sailpoint.v2024.models.common_access_id_status import CommonAccessIDStatus
from sailpoint.v2024.models.common_access_item_request import CommonAccessItemRequest
from sailpoint.v2024.models.common_access_item_response import CommonAccessItemResponse
from sailpoint.v2024.models.common_access_response import CommonAccessResponse

from sailpoint.v2024.api_client import ApiClient, RequestSerialized
from sailpoint.v2024.api_response import ApiResponse
from sailpoint.v2024.rest import RESTResponseType


class IAICommonAccessApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_common_access(
        self,
        common_access_item_request: CommonAccessItemRequest,
        x_sail_point_experimental: Annotated[StrictStr, Field(description="Use this header to enable this experimental API.")] = 'true',
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CommonAccessItemResponse:
        """Create common access items

        This API is used to add roles/access profiles to the list of common access for a customer. Requires authorization scope of iai:access-modeling:create

        :param x_sail_point_experimental: Use this header to enable this experimental API. (required)
        :type x_sail_point_experimental: str
        :param common_access_item_request: (required)
        :type common_access_item_request: CommonAccessItemRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_common_access_serialize(
            x_sail_point_experimental=x_sail_point_experimental,
            common_access_item_request=common_access_item_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "CommonAccessItemResponse",
            '400': "ErrorResponseDto",
            '401': "ListAccessProfiles401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessProfiles429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_common_access_with_http_info(
        self,
        common_access_item_request: CommonAccessItemRequest,
        x_sail_point_experimental: Annotated[StrictStr, Field(description="Use this header to enable this experimental API.")] = 'true',
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CommonAccessItemResponse]:
        """Create common access items

        This API is used to add roles/access profiles to the list of common access for a customer. Requires authorization scope of iai:access-modeling:create

        :param x_sail_point_experimental: Use this header to enable this experimental API. (required)
        :type x_sail_point_experimental: str
        :param common_access_item_request: (required)
        :type common_access_item_request: CommonAccessItemRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_common_access_serialize(
            x_sail_point_experimental=x_sail_point_experimental,
            common_access_item_request=common_access_item_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "CommonAccessItemResponse",
            '400': "ErrorResponseDto",
            '401': "ListAccessProfiles401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessProfiles429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_common_access_without_preload_content(
        self,
        common_access_item_request: CommonAccessItemRequest,
        x_sail_point_experimental: Annotated[StrictStr, Field(description="Use this header to enable this experimental API.")] = 'true',
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create common access items

        This API is used to add roles/access profiles to the list of common access for a customer. Requires authorization scope of iai:access-modeling:create

        :param x_sail_point_experimental: Use this header to enable this experimental API. (required)
        :type x_sail_point_experimental: str
        :param common_access_item_request: (required)
        :type common_access_item_request: CommonAccessItemRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_common_access_serialize(
            x_sail_point_experimental=x_sail_point_experimental,
            common_access_item_request=common_access_item_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "CommonAccessItemResponse",
            '400': "ErrorResponseDto",
            '401': "ListAccessProfiles401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessProfiles429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_common_access_serialize(
        self,
        x_sail_point_experimental,
        common_access_item_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if x_sail_point_experimental is not None:
            _header_params['X-SailPoint-Experimental'] = x_sail_point_experimental
        # process the form parameters
        # process the body parameter
        if common_access_item_request is not None:
            _body_params = common_access_item_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept( _query_params,
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'userAuth', 
            'userAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/common-access',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_common_access(
        self,
        offset: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=250, strict=True, ge=0)]], Field(description="Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        count: Annotated[Optional[StrictBool], Field(description="If *true* it will populate the *X-Total-Count* response header with the number of results that would be returned if *limit* and *offset* were ignored.  Since requesting a total count can have a performance impact, it is recommended not to send **count=true** if that value will not be used.  See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        filters: Annotated[Optional[StrictStr], Field(description="Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)  Filtering is supported for the following fields and operators:  **status**: *eq, sw*  **reviewedByUser** *eq*  **access.id**: *eq, sw*  **access.type**: *eq*  **access.name**: *sw, eq*  **access.description**: *sw, eq*")] = None,
        sorters: Annotated[Optional[StrictStr], Field(description="Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **access.name, status**  By default the common access items are sorted by name, ascending.")] = None,
        x_sail_point_experimental: Annotated[StrictStr, Field(description="Use this header to enable this experimental API.")] = 'true',
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[CommonAccessResponse]:
        """Get a paginated list of common access

        This endpoint returns the current common access for a customer. The returned items can be filtered and sorted. Requires authorization scope of iai:access-modeling:read

        :param x_sail_point_experimental: Use this header to enable this experimental API. (required)
        :type x_sail_point_experimental: str
        :param offset: Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type offset: int
        :param limit: Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type limit: int
        :param count: If *true* it will populate the *X-Total-Count* response header with the number of results that would be returned if *limit* and *offset* were ignored.  Since requesting a total count can have a performance impact, it is recommended not to send **count=true** if that value will not be used.  See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type count: bool
        :param filters: Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)  Filtering is supported for the following fields and operators:  **status**: *eq, sw*  **reviewedByUser** *eq*  **access.id**: *eq, sw*  **access.type**: *eq*  **access.name**: *sw, eq*  **access.description**: *sw, eq*
        :type filters: str
        :param sorters: Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **access.name, status**  By default the common access items are sorted by name, ascending.
        :type sorters: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_common_access_serialize(
            x_sail_point_experimental=x_sail_point_experimental,
            offset=offset,
            limit=limit,
            count=count,
            filters=filters,
            sorters=sorters,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CommonAccessResponse]",
            '400': "ErrorResponseDto",
            '401': "ListAccessProfiles401Response",
            '403': "ErrorResponseDto",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_common_access_with_http_info(
        self,
        offset: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=250, strict=True, ge=0)]], Field(description="Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        count: Annotated[Optional[StrictBool], Field(description="If *true* it will populate the *X-Total-Count* response header with the number of results that would be returned if *limit* and *offset* were ignored.  Since requesting a total count can have a performance impact, it is recommended not to send **count=true** if that value will not be used.  See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        filters: Annotated[Optional[StrictStr], Field(description="Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)  Filtering is supported for the following fields and operators:  **status**: *eq, sw*  **reviewedByUser** *eq*  **access.id**: *eq, sw*  **access.type**: *eq*  **access.name**: *sw, eq*  **access.description**: *sw, eq*")] = None,
        sorters: Annotated[Optional[StrictStr], Field(description="Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **access.name, status**  By default the common access items are sorted by name, ascending.")] = None,
        x_sail_point_experimental: Annotated[StrictStr, Field(description="Use this header to enable this experimental API.")] = 'true',
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[CommonAccessResponse]]:
        """Get a paginated list of common access

        This endpoint returns the current common access for a customer. The returned items can be filtered and sorted. Requires authorization scope of iai:access-modeling:read

        :param x_sail_point_experimental: Use this header to enable this experimental API. (required)
        :type x_sail_point_experimental: str
        :param offset: Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type offset: int
        :param limit: Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type limit: int
        :param count: If *true* it will populate the *X-Total-Count* response header with the number of results that would be returned if *limit* and *offset* were ignored.  Since requesting a total count can have a performance impact, it is recommended not to send **count=true** if that value will not be used.  See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type count: bool
        :param filters: Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)  Filtering is supported for the following fields and operators:  **status**: *eq, sw*  **reviewedByUser** *eq*  **access.id**: *eq, sw*  **access.type**: *eq*  **access.name**: *sw, eq*  **access.description**: *sw, eq*
        :type filters: str
        :param sorters: Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **access.name, status**  By default the common access items are sorted by name, ascending.
        :type sorters: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_common_access_serialize(
            x_sail_point_experimental=x_sail_point_experimental,
            offset=offset,
            limit=limit,
            count=count,
            filters=filters,
            sorters=sorters,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CommonAccessResponse]",
            '400': "ErrorResponseDto",
            '401': "ListAccessProfiles401Response",
            '403': "ErrorResponseDto",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_common_access_without_preload_content(
        self,
        offset: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=250, strict=True, ge=0)]], Field(description="Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        count: Annotated[Optional[StrictBool], Field(description="If *true* it will populate the *X-Total-Count* response header with the number of results that would be returned if *limit* and *offset* were ignored.  Since requesting a total count can have a performance impact, it is recommended not to send **count=true** if that value will not be used.  See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.")] = None,
        filters: Annotated[Optional[StrictStr], Field(description="Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)  Filtering is supported for the following fields and operators:  **status**: *eq, sw*  **reviewedByUser** *eq*  **access.id**: *eq, sw*  **access.type**: *eq*  **access.name**: *sw, eq*  **access.description**: *sw, eq*")] = None,
        sorters: Annotated[Optional[StrictStr], Field(description="Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **access.name, status**  By default the common access items are sorted by name, ascending.")] = None,
        x_sail_point_experimental: Annotated[StrictStr, Field(description="Use this header to enable this experimental API.")] = 'true',
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a paginated list of common access

        This endpoint returns the current common access for a customer. The returned items can be filtered and sorted. Requires authorization scope of iai:access-modeling:read

        :param x_sail_point_experimental: Use this header to enable this experimental API. (required)
        :type x_sail_point_experimental: str
        :param offset: Offset into the full result set. Usually specified with *limit* to paginate through the results. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type offset: int
        :param limit: Max number of results to return. See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type limit: int
        :param count: If *true* it will populate the *X-Total-Count* response header with the number of results that would be returned if *limit* and *offset* were ignored.  Since requesting a total count can have a performance impact, it is recommended not to send **count=true** if that value will not be used.  See [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters) for more information.
        :type count: bool
        :param filters: Filter results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#filtering-results)  Filtering is supported for the following fields and operators:  **status**: *eq, sw*  **reviewedByUser** *eq*  **access.id**: *eq, sw*  **access.type**: *eq*  **access.name**: *sw, eq*  **access.description**: *sw, eq*
        :type filters: str
        :param sorters: Sort results using the standard syntax described in [V3 API Standard Collection Parameters](https://developer.sailpoint.com/idn/api/standard-collection-parameters#sorting-results)  Sorting is supported for the following fields: **access.name, status**  By default the common access items are sorted by name, ascending.
        :type sorters: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_common_access_serialize(
            x_sail_point_experimental=x_sail_point_experimental,
            offset=offset,
            limit=limit,
            count=count,
            filters=filters,
            sorters=sorters,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CommonAccessResponse]",
            '400': "ErrorResponseDto",
            '401': "ListAccessProfiles401Response",
            '403': "ErrorResponseDto",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_common_access_serialize(
        self,
        x_sail_point_experimental,
        offset,
        limit,
        count,
        filters,
        sorters,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if count is not None:
            
            _query_params.append(('count', count))
            
        if filters is not None:
            
            _query_params.append(('filters', filters))
            
        if sorters is not None:
            
            _query_params.append(('sorters', sorters))
            
        # process the header parameters
        if x_sail_point_experimental is not None:
            _header_params['X-SailPoint-Experimental'] = x_sail_point_experimental
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept( _query_params,
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'userAuth', 
            'userAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/common-access',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_common_access_status_in_bulk(
        self,
        common_access_id_status: Annotated[List[CommonAccessIDStatus], Field(description="Confirm or deny in bulk the common access ids that are (or aren't) common access")],
        x_sail_point_experimental: Annotated[StrictStr, Field(description="Use this header to enable this experimental API.")] = 'true',
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Bulk update common access status

        This submits an update request to the common access application. At this time there are no parameters. Requires authorization scope of iai:access-modeling:update

        :param x_sail_point_experimental: Use this header to enable this experimental API. (required)
        :type x_sail_point_experimental: str
        :param common_access_id_status: Confirm or deny in bulk the common access ids that are (or aren't) common access (required)
        :type common_access_id_status: List[CommonAccessIDStatus]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_common_access_status_in_bulk_serialize(
            x_sail_point_experimental=x_sail_point_experimental,
            common_access_id_status=common_access_id_status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "object",
            '400': "ErrorResponseDto",
            '401': "ListAccessProfiles401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessProfiles429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_common_access_status_in_bulk_with_http_info(
        self,
        common_access_id_status: Annotated[List[CommonAccessIDStatus], Field(description="Confirm or deny in bulk the common access ids that are (or aren't) common access")],
        x_sail_point_experimental: Annotated[StrictStr, Field(description="Use this header to enable this experimental API.")] = 'true',
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Bulk update common access status

        This submits an update request to the common access application. At this time there are no parameters. Requires authorization scope of iai:access-modeling:update

        :param x_sail_point_experimental: Use this header to enable this experimental API. (required)
        :type x_sail_point_experimental: str
        :param common_access_id_status: Confirm or deny in bulk the common access ids that are (or aren't) common access (required)
        :type common_access_id_status: List[CommonAccessIDStatus]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_common_access_status_in_bulk_serialize(
            x_sail_point_experimental=x_sail_point_experimental,
            common_access_id_status=common_access_id_status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "object",
            '400': "ErrorResponseDto",
            '401': "ListAccessProfiles401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessProfiles429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_common_access_status_in_bulk_without_preload_content(
        self,
        common_access_id_status: Annotated[List[CommonAccessIDStatus], Field(description="Confirm or deny in bulk the common access ids that are (or aren't) common access")],
        x_sail_point_experimental: Annotated[StrictStr, Field(description="Use this header to enable this experimental API.")] = 'true',
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Bulk update common access status

        This submits an update request to the common access application. At this time there are no parameters. Requires authorization scope of iai:access-modeling:update

        :param x_sail_point_experimental: Use this header to enable this experimental API. (required)
        :type x_sail_point_experimental: str
        :param common_access_id_status: Confirm or deny in bulk the common access ids that are (or aren't) common access (required)
        :type common_access_id_status: List[CommonAccessIDStatus]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_common_access_status_in_bulk_serialize(
            x_sail_point_experimental=x_sail_point_experimental,
            common_access_id_status=common_access_id_status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "object",
            '400': "ErrorResponseDto",
            '401': "ListAccessProfiles401Response",
            '403': "ErrorResponseDto",
            '429': "ListAccessProfiles429Response",
            '500': "ErrorResponseDto",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_common_access_status_in_bulk_serialize(
        self,
        x_sail_point_experimental,
        common_access_id_status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'CommonAccessIDStatus': '',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if x_sail_point_experimental is not None:
            _header_params['X-SailPoint-Experimental'] = x_sail_point_experimental
        # process the form parameters
        # process the body parameter
        if common_access_id_status is not None:
            _body_params = common_access_id_status


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept( _query_params,
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'userAuth', 
            'userAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/common-access/update-status',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.service_desk_integration_api import ServiceDeskIntegrationApi


class TestServiceDeskIntegrationApi(unittest.TestCase):
    """ServiceDeskIntegrationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ServiceDeskIntegrationApi()

    def tearDown(self) -> None:
        pass

    def test_create_service_desk_integration(self) -> None:
        """Test case for create_service_desk_integration

        Create new service desk integration
        """
        pass

    def test_delete_service_desk_integration(self) -> None:
        """Test case for delete_service_desk_integration

        Delete a service desk integration
        """
        pass

    def test_get_service_desk_integration(self) -> None:
        """Test case for get_service_desk_integration

        Get a service desk integration
        """
        pass

    def test_get_service_desk_integration_list(self) -> None:
        """Test case for get_service_desk_integration_list

        List existing service desk integrations
        """
        pass

    def test_get_service_desk_integration_template(self) -> None:
        """Test case for get_service_desk_integration_template

        Service desk integration template by scriptname
        """
        pass

    def test_get_service_desk_integration_types(self) -> None:
        """Test case for get_service_desk_integration_types

        List service desk integration types
        """
        pass

    def test_get_status_check_details(self) -> None:
        """Test case for get_status_check_details

        Get the time check configuration
        """
        pass

    def test_patch_service_desk_integration(self) -> None:
        """Test case for patch_service_desk_integration

        Patch a service desk integration
        """
        pass

    def test_put_service_desk_integration(self) -> None:
        """Test case for put_service_desk_integration

        Update a service desk integration
        """
        pass

    def test_update_status_check_details(self) -> None:
        """Test case for update_status_check_details

        Update the time check configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.v2025.models.account_activity_item import AccountActivityItem
from sailpoint.v2025.models.completion_status import CompletionStatus
from sailpoint.v2025.models.execution_status import ExecutionStatus
from sailpoint.v2025.models.identity_summary import IdentitySummary
from typing import Optional, Set
from typing_extensions import Self

class AccountActivity(BaseModel):
    """
    AccountActivity
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="Id of the account activity")
    name: Optional[StrictStr] = Field(default=None, description="The name of the activity")
    created: Optional[datetime] = Field(default=None, description="When the activity was first created")
    modified: Optional[datetime] = Field(default=None, description="When the activity was last modified")
    completed: Optional[datetime] = Field(default=None, description="When the activity was completed")
    completion_status: Optional[CompletionStatus] = Field(default=None, alias="completionStatus")
    type: Optional[StrictStr] = Field(default=None, description="The type of action the activity performed.  Please see the following list of types.  This list may grow over time.  - CloudAutomated - IdentityAttributeUpdate - appRequest - LifecycleStateChange - AccountStateUpdate - AccountAttributeUpdate - CloudPasswordRequest - Attribute Synchronization Refresh - Certification - Identity Refresh - Lifecycle Change Refresh   [Learn more here](https://documentation.sailpoint.com/saas/help/search/searchable-fields.html#searching-account-activity-data). ")
    requester_identity_summary: Optional[IdentitySummary] = Field(default=None, alias="requesterIdentitySummary")
    target_identity_summary: Optional[IdentitySummary] = Field(default=None, alias="targetIdentitySummary")
    errors: Optional[List[StrictStr]] = Field(default=None, description="A list of error messages, if any, that were encountered.")
    warnings: Optional[List[StrictStr]] = Field(default=None, description="A list of warning messages, if any, that were encountered.")
    items: Optional[List[AccountActivityItem]] = Field(default=None, description="Individual actions performed as part of this account activity")
    execution_status: Optional[ExecutionStatus] = Field(default=None, alias="executionStatus")
    client_metadata: Optional[Dict[str, StrictStr]] = Field(default=None, description="Arbitrary key-value pairs, if any were included in the corresponding access request", alias="clientMetadata")
    __properties: ClassVar[List[str]] = ["id", "name", "created", "modified", "completed", "completionStatus", "type", "requesterIdentitySummary", "targetIdentitySummary", "errors", "warnings", "items", "executionStatus", "clientMetadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AccountActivity from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of requester_identity_summary
        if self.requester_identity_summary:
            _dict['requesterIdentitySummary'] = self.requester_identity_summary.to_dict()
        # override the default output from pydantic by calling `to_dict()` of target_identity_summary
        if self.target_identity_summary:
            _dict['targetIdentitySummary'] = self.target_identity_summary.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item_items in self.items:
                if _item_items:
                    _items.append(_item_items.to_dict())
            _dict['items'] = _items
        # set to None if modified (nullable) is None
        # and model_fields_set contains the field
        if self.modified is None and "modified" in self.model_fields_set:
            _dict['modified'] = None

        # set to None if completed (nullable) is None
        # and model_fields_set contains the field
        if self.completed is None and "completed" in self.model_fields_set:
            _dict['completed'] = None

        # set to None if completion_status (nullable) is None
        # and model_fields_set contains the field
        if self.completion_status is None and "completion_status" in self.model_fields_set:
            _dict['completionStatus'] = None

        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        # set to None if requester_identity_summary (nullable) is None
        # and model_fields_set contains the field
        if self.requester_identity_summary is None and "requester_identity_summary" in self.model_fields_set:
            _dict['requesterIdentitySummary'] = None

        # set to None if target_identity_summary (nullable) is None
        # and model_fields_set contains the field
        if self.target_identity_summary is None and "target_identity_summary" in self.model_fields_set:
            _dict['targetIdentitySummary'] = None

        # set to None if errors (nullable) is None
        # and model_fields_set contains the field
        if self.errors is None and "errors" in self.model_fields_set:
            _dict['errors'] = None

        # set to None if warnings (nullable) is None
        # and model_fields_set contains the field
        if self.warnings is None and "warnings" in self.model_fields_set:
            _dict['warnings'] = None

        # set to None if items (nullable) is None
        # and model_fields_set contains the field
        if self.items is None and "items" in self.model_fields_set:
            _dict['items'] = None

        # set to None if client_metadata (nullable) is None
        # and model_fields_set contains the field
        if self.client_metadata is None and "client_metadata" in self.model_fields_set:
            _dict['clientMetadata'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AccountActivity from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "completed": obj.get("completed"),
            "completionStatus": obj.get("completionStatus"),
            "type": obj.get("type"),
            "requesterIdentitySummary": IdentitySummary.from_dict(obj["requesterIdentitySummary"]) if obj.get("requesterIdentitySummary") is not None else None,
            "targetIdentitySummary": IdentitySummary.from_dict(obj["targetIdentitySummary"]) if obj.get("targetIdentitySummary") is not None else None,
            "errors": obj.get("errors"),
            "warnings": obj.get("warnings"),
            "items": [AccountActivityItem.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "executionStatus": obj.get("executionStatus"),
            "clientMetadata": obj.get("clientMetadata")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PasswordInfoAccount(BaseModel):
    """
    PasswordInfoAccount
    """ # noqa: E501
    account_id: Optional[StrictStr] = Field(default=None, description="Account ID of the account. This is specified per account schema in the source configuration. It is used to distinguish accounts. More info can be found here https://community.sailpoint.com/t5/IdentityNow-Connectors/How-do-I-designate-an-account-attribute-as-the-Account-ID-for-a/ta-p/80350", alias="accountId")
    account_name: Optional[StrictStr] = Field(default=None, description="Display name of the account. This is specified per account schema in the source configuration. It is used to display name of the account. More info can be found here https://community.sailpoint.com/t5/IdentityNow-Connectors/How-do-I-designate-an-account-attribute-as-the-Account-Name-for/ta-p/74008", alias="accountName")
    __properties: ClassVar[List[str]] = ["accountId", "accountName"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PasswordInfoAccount from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PasswordInfoAccount from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accountId": obj.get("accountId"),
            "accountName": obj.get("accountName")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Optional
from sailpoint.v2024.models.accounts_export_report_arguments import AccountsExportReportArguments
from sailpoint.v2024.models.identities_details_report_arguments import IdentitiesDetailsReportArguments
from sailpoint.v2024.models.identities_report_arguments import IdentitiesReportArguments
from sailpoint.v2024.models.identity_profile_identity_error_report_arguments import IdentityProfileIdentityErrorReportArguments
from sailpoint.v2024.models.orphan_identities_report_arguments import OrphanIdentitiesReportArguments
from sailpoint.v2024.models.search_export_report_arguments import SearchExportReportArguments
from sailpoint.v2024.models.uncorrelated_accounts_report_arguments import UncorrelatedAccountsReportArguments
from typing import Union, Any, List, Set, TYPE_CHECKING, Optional, Dict
from typing_extensions import Literal, Self
from pydantic import Field

REPORTDETAILSARGUMENTS_ANY_OF_SCHEMAS = ["AccountsExportReportArguments", "IdentitiesDetailsReportArguments", "IdentitiesReportArguments", "IdentityProfileIdentityErrorReportArguments", "OrphanIdentitiesReportArguments", "SearchExportReportArguments", "UncorrelatedAccountsReportArguments"]

class ReportDetailsArguments(BaseModel):
    """
    The string-object map(dictionary) with the arguments needed for report processing.
    """

    # data type: AccountsExportReportArguments
    anyof_schema_1_validator: Optional[AccountsExportReportArguments] = None
    # data type: IdentitiesDetailsReportArguments
    anyof_schema_2_validator: Optional[IdentitiesDetailsReportArguments] = None
    # data type: IdentitiesReportArguments
    anyof_schema_3_validator: Optional[IdentitiesReportArguments] = None
    # data type: IdentityProfileIdentityErrorReportArguments
    anyof_schema_4_validator: Optional[IdentityProfileIdentityErrorReportArguments] = None
    # data type: OrphanIdentitiesReportArguments
    anyof_schema_5_validator: Optional[OrphanIdentitiesReportArguments] = None
    # data type: SearchExportReportArguments
    anyof_schema_6_validator: Optional[SearchExportReportArguments] = None
    # data type: UncorrelatedAccountsReportArguments
    anyof_schema_7_validator: Optional[UncorrelatedAccountsReportArguments] = None
    if TYPE_CHECKING:
        actual_instance: Optional[Union[AccountsExportReportArguments, IdentitiesDetailsReportArguments, IdentitiesReportArguments, IdentityProfileIdentityErrorReportArguments, OrphanIdentitiesReportArguments, SearchExportReportArguments, UncorrelatedAccountsReportArguments]] = None
    else:
        actual_instance: Any = None
    any_of_schemas: Set[str] = { "AccountsExportReportArguments", "IdentitiesDetailsReportArguments", "IdentitiesReportArguments", "IdentityProfileIdentityErrorReportArguments", "OrphanIdentitiesReportArguments", "SearchExportReportArguments", "UncorrelatedAccountsReportArguments" }

    model_config = {
        "validate_assignment": True,
        "protected_namespaces": (),
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_anyof(cls, v):
        instance = ReportDetailsArguments.model_construct()
        error_messages = []
        # validate data type: AccountsExportReportArguments
        if not isinstance(v, AccountsExportReportArguments):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AccountsExportReportArguments`")
        else:
            return v

        # validate data type: IdentitiesDetailsReportArguments
        if not isinstance(v, IdentitiesDetailsReportArguments):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IdentitiesDetailsReportArguments`")
        else:
            return v

        # validate data type: IdentitiesReportArguments
        if not isinstance(v, IdentitiesReportArguments):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IdentitiesReportArguments`")
        else:
            return v

        # validate data type: IdentityProfileIdentityErrorReportArguments
        if not isinstance(v, IdentityProfileIdentityErrorReportArguments):
            error_messages.append(f"Error! Input type `{type(v)}` is not `IdentityProfileIdentityErrorReportArguments`")
        else:
            return v

        # validate data type: OrphanIdentitiesReportArguments
        if not isinstance(v, OrphanIdentitiesReportArguments):
            error_messages.append(f"Error! Input type `{type(v)}` is not `OrphanIdentitiesReportArguments`")
        else:
            return v

        # validate data type: SearchExportReportArguments
        if not isinstance(v, SearchExportReportArguments):
            error_messages.append(f"Error! Input type `{type(v)}` is not `SearchExportReportArguments`")
        else:
            return v

        # validate data type: UncorrelatedAccountsReportArguments
        if not isinstance(v, UncorrelatedAccountsReportArguments):
            error_messages.append(f"Error! Input type `{type(v)}` is not `UncorrelatedAccountsReportArguments`")
        else:
            return v

        if error_messages:
            # no match
            raise ValueError("No match found when setting the actual_instance in ReportDetailsArguments with anyOf schemas: AccountsExportReportArguments, IdentitiesDetailsReportArguments, IdentitiesReportArguments, IdentityProfileIdentityErrorReportArguments, OrphanIdentitiesReportArguments, SearchExportReportArguments, UncorrelatedAccountsReportArguments. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        # anyof_schema_1_validator: Optional[AccountsExportReportArguments] = None
        try:
            instance.actual_instance = AccountsExportReportArguments.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_2_validator: Optional[IdentitiesDetailsReportArguments] = None
        try:
            instance.actual_instance = IdentitiesDetailsReportArguments.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_3_validator: Optional[IdentitiesReportArguments] = None
        try:
            instance.actual_instance = IdentitiesReportArguments.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_4_validator: Optional[IdentityProfileIdentityErrorReportArguments] = None
        try:
            instance.actual_instance = IdentityProfileIdentityErrorReportArguments.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_5_validator: Optional[OrphanIdentitiesReportArguments] = None
        try:
            instance.actual_instance = OrphanIdentitiesReportArguments.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_6_validator: Optional[SearchExportReportArguments] = None
        try:
            instance.actual_instance = SearchExportReportArguments.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_7_validator: Optional[UncorrelatedAccountsReportArguments] = None
        try:
            instance.actual_instance = UncorrelatedAccountsReportArguments.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))

        if error_messages:
            # no match
            raise ValueError("No match found when deserializing the JSON string into ReportDetailsArguments with anyOf schemas: AccountsExportReportArguments, IdentitiesDetailsReportArguments, IdentitiesReportArguments, IdentityProfileIdentityErrorReportArguments, OrphanIdentitiesReportArguments, SearchExportReportArguments, UncorrelatedAccountsReportArguments. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], AccountsExportReportArguments, IdentitiesDetailsReportArguments, IdentitiesReportArguments, IdentityProfileIdentityErrorReportArguments, OrphanIdentitiesReportArguments, SearchExportReportArguments, UncorrelatedAccountsReportArguments]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.identity_history_api import IdentityHistoryApi


class TestIdentityHistoryApi(unittest.TestCase):
    """IdentityHistoryApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentityHistoryApi()

    def tearDown(self) -> None:
        pass

    def test_compare_identity_snapshots(self) -> None:
        """Test case for compare_identity_snapshots

        Gets a difference of count for each access item types for the given identity between 2 snapshots
        """
        pass

    def test_compare_identity_snapshots_access_type(self) -> None:
        """Test case for compare_identity_snapshots_access_type

        Gets a list of differences of specific accesstype for the given identity between 2 snapshots
        """
        pass

    def test_get_historical_identity(self) -> None:
        """Test case for get_historical_identity

        Get latest snapshot of identity
        """
        pass

    def test_get_historical_identity_events(self) -> None:
        """Test case for get_historical_identity_events

        List identity event history
        """
        pass

    def test_get_identity_snapshot(self) -> None:
        """Test case for get_identity_snapshot

        Gets an identity snapshot at a given date
        """
        pass

    def test_get_identity_snapshot_summary(self) -> None:
        """Test case for get_identity_snapshot_summary

        Gets the summary for the event count for a specific identity
        """
        pass

    def test_get_identity_start_date(self) -> None:
        """Test case for get_identity_start_date

        Gets the start date of the identity
        """
        pass

    def test_list_historical_identities(self) -> None:
        """Test case for list_historical_identities

        Lists all the identities
        """
        pass

    def test_list_identity_access_items(self) -> None:
        """Test case for list_identity_access_items

        List access items by identity
        """
        pass

    def test_list_identity_snapshot_access_items(self) -> None:
        """Test case for list_identity_snapshot_access_items

        Get identity access items snapshot
        """
        pass

    def test_list_identity_snapshots(self) -> None:
        """Test case for list_identity_snapshots

        Lists all the snapshots for the identity
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.custom_password_instructions_api import CustomPasswordInstructionsApi


class TestCustomPasswordInstructionsApi(unittest.TestCase):
    """CustomPasswordInstructionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomPasswordInstructionsApi()

    def tearDown(self) -> None:
        pass

    def test_create_custom_password_instructions(self) -> None:
        """Test case for create_custom_password_instructions

        Create custom password instructions
        """
        pass

    def test_delete_custom_password_instructions(self) -> None:
        """Test case for delete_custom_password_instructions

        Delete custom password instructions by page id
        """
        pass

    def test_get_custom_password_instructions(self) -> None:
        """Test case for get_custom_password_instructions

        Get custom password instructions by page id
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class RightSetDTO(BaseModel):
    """
    A RightSetDTO represents a collection of rights that assigned to capability or scope, enabling them to possess specific rights to access corresponding APIs.
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The unique identifier of the RightSet.")
    name: Optional[StrictStr] = Field(default=None, description="The human-readable name of the RightSet.")
    description: Optional[StrictStr] = Field(default=None, description="A human-readable description of the RightSet.")
    category: Optional[StrictStr] = Field(default=None, description="The category of the RightSet.")
    rights: Optional[List[StrictStr]] = Field(default=None, description="Right is the most granular unit that determines specific API permissions, this is a list of rights associated with the RightSet.")
    right_set_ids: Optional[List[StrictStr]] = Field(default=None, description="List of unique identifiers for related RightSets, current RightSet contains rights from these RightSets.", alias="rightSetIds")
    ui_assignable_child_right_set_ids: Optional[List[StrictStr]] = Field(default=None, description="List of unique identifiers for UI-assignable child RightSets, used to build UI components.", alias="uiAssignableChildRightSetIds")
    ui_assignable: Optional[StrictBool] = Field(default=False, description="Indicates whether the RightSet is UI-assignable.", alias="uiAssignable")
    translated_name: Optional[StrictStr] = Field(default=None, description="The translated name of the RightSet.", alias="translatedName")
    translated_description: Optional[StrictStr] = Field(default=None, description="The translated description of the RightSet.", alias="translatedDescription")
    parent_id: Optional[StrictStr] = Field(default=None, description="The unique identifier of the parent RightSet for UI Assignable RightSet.", alias="parentId")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "category", "rights", "rightSetIds", "uiAssignableChildRightSetIds", "uiAssignable", "translatedName", "translatedDescription", "parentId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RightSetDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if translated_description (nullable) is None
        # and model_fields_set contains the field
        if self.translated_description is None and "translated_description" in self.model_fields_set:
            _dict['translatedDescription'] = None

        # set to None if parent_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_id is None and "parent_id" in self.model_fields_set:
            _dict['parentId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RightSetDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "category": obj.get("category"),
            "rights": obj.get("rights"),
            "rightSetIds": obj.get("rightSetIds"),
            "uiAssignableChildRightSetIds": obj.get("uiAssignableChildRightSetIds"),
            "uiAssignable": obj.get("uiAssignable") if obj.get("uiAssignable") is not None else False,
            "translatedName": obj.get("translatedName"),
            "translatedDescription": obj.get("translatedDescription"),
            "parentId": obj.get("parentId")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.beta.models.requested_item_details import RequestedItemDetails
from typing import Optional, Set
from typing_extensions import Self

class AccessRequestTracking(BaseModel):
    """
    AccessRequestTracking
    """ # noqa: E501
    requested_for: Optional[StrictStr] = Field(default=None, description="The identity id in which the access request is for.", alias="requestedFor")
    requested_items_details: Optional[List[RequestedItemDetails]] = Field(default=None, description="The details of the item requested.", alias="requestedItemsDetails")
    attributes_hash: Optional[StrictInt] = Field(default=None, description="a hash representation of the access requested, useful for longer term tracking client side.", alias="attributesHash")
    access_request_ids: Optional[List[StrictStr]] = Field(default=None, description="a list of access request identifiers, generally only one will be populated, but high volume requested may result in multiple ids.", alias="accessRequestIds")
    __properties: ClassVar[List[str]] = ["requestedFor", "requestedItemsDetails", "attributesHash", "accessRequestIds"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AccessRequestTracking from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in requested_items_details (list)
        _items = []
        if self.requested_items_details:
            for _item_requested_items_details in self.requested_items_details:
                if _item_requested_items_details:
                    _items.append(_item_requested_items_details.to_dict())
            _dict['requestedItemsDetails'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AccessRequestTracking from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "requestedFor": obj.get("requestedFor"),
            "requestedItemsDetails": [RequestedItemDetails.from_dict(_item) for _item in obj["requestedItemsDetails"]] if obj.get("requestedItemsDetails") is not None else None,
            "attributesHash": obj.get("attributesHash"),
            "accessRequestIds": obj.get("accessRequestIds")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.v2024.models.membership_type import MembershipType
from sailpoint.v2024.models.ref import Ref
from sailpoint.v2024.models.scope import Scope
from sailpoint.v2024.models.visibility_criteria import VisibilityCriteria
from typing import Optional, Set
from typing_extensions import Self

class DataSegment(BaseModel):
    """
    DataSegment
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The segment's ID.")
    name: Optional[StrictStr] = Field(default=None, description="The segment's business name.")
    created: Optional[datetime] = Field(default=None, description="The time when the segment is created.")
    modified: Optional[datetime] = Field(default=None, description="The time when the segment is modified.")
    description: Optional[StrictStr] = Field(default=None, description="The segment's optional description.")
    scopes: Optional[List[Scope]] = Field(default=None, description="List of Scopes that are assigned to the segment")
    member_selection: Optional[List[Ref]] = Field(default=None, description="List of Identities that are assigned to the segment", alias="memberSelection")
    member_filter: Optional[VisibilityCriteria] = Field(default=None, alias="memberFilter")
    membership: Optional[MembershipType] = None
    enabled: Optional[StrictBool] = Field(default=False, description="This boolean indicates whether the segment is currently active. Inactive segments have no effect.")
    published: Optional[StrictBool] = Field(default=False, description="This boolean indicates whether the segment is being applied to the accounts. If unpublished its being actively modified to until published")
    __properties: ClassVar[List[str]] = ["id", "name", "created", "modified", "description", "scopes", "memberSelection", "memberFilter", "membership", "enabled", "published"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataSegment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in scopes (list)
        _items = []
        if self.scopes:
            for _item_scopes in self.scopes:
                if _item_scopes:
                    _items.append(_item_scopes.to_dict())
            _dict['scopes'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in member_selection (list)
        _items = []
        if self.member_selection:
            for _item_member_selection in self.member_selection:
                if _item_member_selection:
                    _items.append(_item_member_selection.to_dict())
            _dict['memberSelection'] = _items
        # override the default output from pydantic by calling `to_dict()` of member_filter
        if self.member_filter:
            _dict['memberFilter'] = self.member_filter.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataSegment from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "description": obj.get("description"),
            "scopes": [Scope.from_dict(_item) for _item in obj["scopes"]] if obj.get("scopes") is not None else None,
            "memberSelection": [Ref.from_dict(_item) for _item in obj["memberSelection"]] if obj.get("memberSelection") is not None else None,
            "memberFilter": VisibilityCriteria.from_dict(obj["memberFilter"]) if obj.get("memberFilter") is not None else None,
            "membership": obj.get("membership"),
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else False,
            "published": obj.get("published") if obj.get("published") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.machine_classification_config_api import MachineClassificationConfigApi


class TestMachineClassificationConfigApi(unittest.TestCase):
    """MachineClassificationConfigApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MachineClassificationConfigApi()

    def tearDown(self) -> None:
        pass

    def test_delete_machine_classification_config(self) -> None:
        """Test case for delete_machine_classification_config

        Delete source's classification config
        """
        pass

    def test_get_machine_classification_config(self) -> None:
        """Test case for get_machine_classification_config

        Machine classification config for source
        """
        pass

    def test_set_machine_classification_config(self) -> None:
        """Test case for set_machine_classification_config

        Update source's classification config
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.v2024.models.identity_reference import IdentityReference
from sailpoint.v2024.models.public_identity_attributes_inner import PublicIdentityAttributesInner
from typing import Optional, Set
from typing_extensions import Self

class PublicIdentity(BaseModel):
    """
    Details about a public identity
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="Identity id")
    name: Optional[StrictStr] = Field(default=None, description="Human-readable display name of identity.")
    alias: Optional[StrictStr] = Field(default=None, description="Alternate unique identifier for the identity.")
    email: Optional[StrictStr] = Field(default=None, description="Email address of identity.")
    status: Optional[StrictStr] = Field(default=None, description="The lifecycle status for the identity")
    identity_state: Optional[StrictStr] = Field(default=None, description="The current state of the identity, which determines how Identity Security Cloud interacts with the identity. An identity that is Active will be included identity picklists in Request Center, identity processing, and more. Identities that are Inactive will be excluded from these features. ", alias="identityState")
    manager: Optional[IdentityReference] = None
    attributes: Optional[List[PublicIdentityAttributesInner]] = Field(default=None, description="The public identity attributes of the identity")
    __properties: ClassVar[List[str]] = ["id", "name", "alias", "email", "status", "identityState", "manager", "attributes"]

    @field_validator('identity_state')
    def identity_state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ACTIVE', 'INACTIVE_SHORT_TERM', 'INACTIVE_LONG_TERM']):
            warnings.warn(f"must be one of enum values ('ACTIVE', 'INACTIVE_SHORT_TERM', 'INACTIVE_LONG_TERM') unknown value: {value}")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PublicIdentity from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of manager
        if self.manager:
            _dict['manager'] = self.manager.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in attributes (list)
        _items = []
        if self.attributes:
            for _item_attributes in self.attributes:
                if _item_attributes:
                    _items.append(_item_attributes.to_dict())
            _dict['attributes'] = _items
        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if identity_state (nullable) is None
        # and model_fields_set contains the field
        if self.identity_state is None and "identity_state" in self.model_fields_set:
            _dict['identityState'] = None

        # set to None if manager (nullable) is None
        # and model_fields_set contains the field
        if self.manager is None and "manager" in self.model_fields_set:
            _dict['manager'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PublicIdentity from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "alias": obj.get("alias"),
            "email": obj.get("email"),
            "status": obj.get("status"),
            "identityState": obj.get("identityState"),
            "manager": IdentityReference.from_dict(obj["manager"]) if obj.get("manager") is not None else None,
            "attributes": [PublicIdentityAttributesInner.from_dict(_item) for _item in obj["attributes"]] if obj.get("attributes") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.saved_search_api import SavedSearchApi


class TestSavedSearchApi(unittest.TestCase):
    """SavedSearchApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SavedSearchApi()

    def tearDown(self) -> None:
        pass

    def test_create_saved_search(self) -> None:
        """Test case for create_saved_search

        Create a saved search
        """
        pass

    def test_delete_saved_search(self) -> None:
        """Test case for delete_saved_search

        Delete document by id
        """
        pass

    def test_execute_saved_search(self) -> None:
        """Test case for execute_saved_search

        Execute a saved search by id
        """
        pass

    def test_get_saved_search(self) -> None:
        """Test case for get_saved_search

        Return saved search by id
        """
        pass

    def test_list_saved_searches(self) -> None:
        """Test case for list_saved_searches

        A list of saved searches
        """
        pass

    def test_put_saved_search(self) -> None:
        """Test case for put_saved_search

        Updates an existing saved search 
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.password_policies_api import PasswordPoliciesApi


class TestPasswordPoliciesApi(unittest.TestCase):
    """PasswordPoliciesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasswordPoliciesApi()

    def tearDown(self) -> None:
        pass

    def test_create_password_policy(self) -> None:
        """Test case for create_password_policy

        Create password policy
        """
        pass

    def test_delete_password_policy(self) -> None:
        """Test case for delete_password_policy

        Delete password policy by id
        """
        pass

    def test_get_password_policy_by_id(self) -> None:
        """Test case for get_password_policy_by_id

        Get password policy by id
        """
        pass

    def test_list_password_policies(self) -> None:
        """Test case for list_password_policies

        List password policies
        """
        pass

    def test_set_password_policy(self) -> None:
        """Test case for set_password_policy

        Update password policy by id
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.v2025.models.base_reference_dto import BaseReferenceDto
from sailpoint.v2025.models.dependant_app_connections_account_source import DependantAppConnectionsAccountSource
from typing import Optional, Set
from typing_extensions import Self

class DependantAppConnections(BaseModel):
    """
    DependantAppConnections
    """ # noqa: E501
    cloud_app_id: Optional[StrictStr] = Field(default=None, description="Id of the connected Application", alias="cloudAppId")
    description: Optional[StrictStr] = Field(default=None, description="Description of the connected Application")
    enabled: Optional[StrictBool] = Field(default=True, description="Is the Application enabled")
    provision_request_enabled: Optional[StrictBool] = Field(default=True, description="Is Provisioning enabled for connected Application", alias="provisionRequestEnabled")
    account_source: Optional[DependantAppConnectionsAccountSource] = Field(default=None, alias="accountSource")
    launcher_count: Optional[StrictInt] = Field(default=None, description="The amount of launchers for connected Application (long type)", alias="launcherCount")
    match_all_account: Optional[StrictBool] = Field(default=False, description="Is Provisioning enabled for connected Application", alias="matchAllAccount")
    owner: Optional[List[BaseReferenceDto]] = Field(default=None, description="The owner of the connected Application")
    app_center_enabled: Optional[StrictBool] = Field(default=False, description="Is App Center enabled for connected Application", alias="appCenterEnabled")
    __properties: ClassVar[List[str]] = ["cloudAppId", "description", "enabled", "provisionRequestEnabled", "accountSource", "launcherCount", "matchAllAccount", "owner", "appCenterEnabled"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DependantAppConnections from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of account_source
        if self.account_source:
            _dict['accountSource'] = self.account_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in owner (list)
        _items = []
        if self.owner:
            for _item_owner in self.owner:
                if _item_owner:
                    _items.append(_item_owner.to_dict())
            _dict['owner'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DependantAppConnections from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cloudAppId": obj.get("cloudAppId"),
            "description": obj.get("description"),
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else True,
            "provisionRequestEnabled": obj.get("provisionRequestEnabled") if obj.get("provisionRequestEnabled") is not None else True,
            "accountSource": DependantAppConnectionsAccountSource.from_dict(obj["accountSource"]) if obj.get("accountSource") is not None else None,
            "launcherCount": obj.get("launcherCount"),
            "matchAllAccount": obj.get("matchAllAccount") if obj.get("matchAllAccount") is not None else False,
            "owner": [BaseReferenceDto.from_dict(_item) for _item in obj["owner"]] if obj.get("owner") is not None else None,
            "appCenterEnabled": obj.get("appCenterEnabled") if obj.get("appCenterEnabled") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.identities_api import IdentitiesApi


class TestIdentitiesApi(unittest.TestCase):
    """IdentitiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentitiesApi()

    def tearDown(self) -> None:
        pass

    def test_delete_identity(self) -> None:
        """Test case for delete_identity

        Delete identity
        """
        pass

    def test_get_identity(self) -> None:
        """Test case for get_identity

        Identity details
        """
        pass

    def test_get_identity_ownership_details(self) -> None:
        """Test case for get_identity_ownership_details

        Get ownership details
        """
        pass

    def test_get_role_assignment(self) -> None:
        """Test case for get_role_assignment

        Role assignment details
        """
        pass

    def test_get_role_assignments(self) -> None:
        """Test case for get_role_assignments

        List role assignments
        """
        pass

    def test_list_identities(self) -> None:
        """Test case for list_identities

        List identities
        """
        pass

    def test_reset_identity(self) -> None:
        """Test case for reset_identity

        Reset an identity
        """
        pass

    def test_send_identity_verification_account_token(self) -> None:
        """Test case for send_identity_verification_account_token

        Send password reset email
        """
        pass

    def test_start_identities_invite(self) -> None:
        """Test case for start_identities_invite

        Invite identities to register
        """
        pass

    def test_start_identity_processing(self) -> None:
        """Test case for start_identity_processing

        Process a list of identityids
        """
        pass

    def test_synchronize_attributes_for_identity(self) -> None:
        """Test case for synchronize_attributes_for_identity

        Attribute synchronization for single identity.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ReassignmentType(str, Enum):
    """
    The approval reassignment type.  * MANUAL_REASSIGNMENT: An approval with this reassignment type has been specifically reassigned by the approval task's owner, from their queue to someone else's.  * AUTOMATIC_REASSIGNMENT: An approval with this reassignment type has been automatically reassigned from another approver's queue, according to that approver's reassignment configuration. The approver's reassignment configuration may be set up to automatically reassign approval tasks for a defined (or possibly open-ended) period of time. * AUTO_ESCALATION: An approval with this reassignment type has been automatically reassigned from another approver's queue, according to the request's escalation configuration. For more information about escalation configuration, refer to [Setting Global Reminders and Escalation Policies](https://documentation.sailpoint.com/saas/help/requests/config_emails.html). * SELF_REVIEW_DELEGATION: An approval with this reassignment type has been automatically reassigned by the system to prevent self-review. This helps prevent situations like a requester being tasked with approving their own request. For more information about preventing self-review, refer to [Self-review Prevention](https://documentation.sailpoint.com/saas/help/users/work_reassignment.html#self-review-prevention) and [Preventing Self-approval](https://documentation.sailpoint.com/saas/help/requests/config_ap_roles.html#preventing-self-approval).
    """

    """
    allowed enum values
    """
    MANUAL_REASSIGNMENT = 'MANUAL_REASSIGNMENT'
    AUTOMATIC_REASSIGNMENT = 'AUTOMATIC_REASSIGNMENT'
    AUTO_ESCALATION = 'AUTO_ESCALATION'
    SELF_REVIEW_DELEGATION = 'SELF_REVIEW_DELEGATION'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ReassignmentType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.v3.models.campaign_all_of_role_composition_campaign_info_remediator_ref import CampaignAllOfRoleCompositionCampaignInfoRemediatorRef
from sailpoint.v3.models.campaign_all_of_search_campaign_info_reviewer import CampaignAllOfSearchCampaignInfoReviewer
from typing import Optional, Set
from typing_extensions import Self

class CampaignAllOfRoleCompositionCampaignInfo(BaseModel):
    """
    Optional configuration options for role composition campaigns.
    """ # noqa: E501
    reviewer: Optional[CampaignAllOfSearchCampaignInfoReviewer] = None
    role_ids: Optional[List[StrictStr]] = Field(default=None, description="Optional list of roles to include in this campaign. Only one of `roleIds` and `query` may be set; if neither are set, all roles are included.", alias="roleIds")
    remediator_ref: CampaignAllOfRoleCompositionCampaignInfoRemediatorRef = Field(alias="remediatorRef")
    query: Optional[StrictStr] = Field(default=None, description="Optional search query to scope this campaign to a set of roles. Only one of `roleIds` and `query` may be set; if neither are set, all roles are included.")
    description: Optional[StrictStr] = Field(default=None, description="Describes this role composition campaign. Intended for storing the query used, and possibly the number of roles selected/available.")
    __properties: ClassVar[List[str]] = ["reviewer", "roleIds", "remediatorRef", "query", "description"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CampaignAllOfRoleCompositionCampaignInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of reviewer
        if self.reviewer:
            _dict['reviewer'] = self.reviewer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of remediator_ref
        if self.remediator_ref:
            _dict['remediatorRef'] = self.remediator_ref.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CampaignAllOfRoleCompositionCampaignInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "reviewer": CampaignAllOfSearchCampaignInfoReviewer.from_dict(obj["reviewer"]) if obj.get("reviewer") is not None else None,
            "roleIds": obj.get("roleIds"),
            "remediatorRef": CampaignAllOfRoleCompositionCampaignInfoRemediatorRef.from_dict(obj["remediatorRef"]) if obj.get("remediatorRef") is not None else None,
            "query": obj.get("query"),
            "description": obj.get("description")
        })
        return _obj





# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.multi_host_integration_api import MultiHostIntegrationApi


class TestMultiHostIntegrationApi(unittest.TestCase):
    """MultiHostIntegrationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MultiHostIntegrationApi()

    def tearDown(self) -> None:
        pass

    def test_create_multi_host_integration(self) -> None:
        """Test case for create_multi_host_integration

        Create multi-host integration
        """
        pass

    def test_create_sources_within_multi_host(self) -> None:
        """Test case for create_sources_within_multi_host

        Create sources within multi-host integration
        """
        pass

    def test_delete_multi_host(self) -> None:
        """Test case for delete_multi_host

        Delete multi-host integration
        """
        pass

    def test_get_acct_aggregation_groups(self) -> None:
        """Test case for get_acct_aggregation_groups

        List account-aggregation-groups by multi-host id
        """
        pass

    def test_get_entitlement_aggregation_groups(self) -> None:
        """Test case for get_entitlement_aggregation_groups

        List entitlement-aggregation-groups by integration id
        """
        pass

    def test_get_multi_host_integrations(self) -> None:
        """Test case for get_multi_host_integrations

        Get multi-host integration by id
        """
        pass

    def test_get_multi_host_integrations_list(self) -> None:
        """Test case for get_multi_host_integrations_list

        List all existing multi-host integrations
        """
        pass

    def test_get_multi_host_source_creation_errors(self) -> None:
        """Test case for get_multi_host_source_creation_errors

        List multi-host source creation errors
        """
        pass

    def test_get_multihost_integration_types(self) -> None:
        """Test case for get_multihost_integration_types

        List multi-host integration types
        """
        pass

    def test_get_sources_within_multi_host(self) -> None:
        """Test case for get_sources_within_multi_host

        List sources within multi-host integration
        """
        pass

    def test_test_connection_multi_host_sources(self) -> None:
        """Test case for test_connection_multi_host_sources

        Test configuration for multi-host integration
        """
        pass

    def test_test_source_connection_multihost(self) -> None:
        """Test case for test_source_connection_multihost

        Test configuration for multi-host integration's single source
        """
        pass

    def test_update_multi_host_sources(self) -> None:
        """Test case for update_multi_host_sources

        Update multi-host integration
        """
        pass


if __name__ == '__main__':
    unittest.main()
